'From Squeak3.2gamma of 15 January 2002 [latest update: #4743] on 20 February 2002 at 1:19:10 am'!
TestCase subclass: #AsyncMessageSecretaryTest
	instanceVariableNames: 'agent1 agent2 '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Kernel-Async'!
TestCase subclass: #DispatchQueueTest
	instanceVariableNames: 'msgQueue gotMessage '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tests-DispatchQueues'!
TestCase subclass: #FutureTestCase
	instanceVariableNames: 'future futureRunSem semTouched count countLimit '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tests-Kernel-Futures'!
TestCase subclass: #TaskTestCase
	instanceVariableNames: 'task taskRunSem semTouched count countLimit '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tests-Kernel-Tasks'!

!AsyncMessageSecretaryTest methodsFor: 'running' stamp: 'rww 1/13/2001 22:25'!
setUp

	agent1 := AsyncMessageSecretary new.
	agent2 := AsyncMessageSecretary new.
	agent1 foreground.
	agent2 background.

! !

!AsyncMessageSecretaryTest methodsFor: 'running' stamp: 'rww 1/12/2001 02:31'!
tearDown

	[	(Delay forSeconds: 1) wait.
		agent1 close.
		agent2 close] fork.
! !

!AsyncMessageSecretaryTest methodsFor: 'running' stamp: 'rw 2/20/2002 01:04'!
testAsyncMsgSend

	| aFuture |
	aFuture := agent1 createFuture.
	aFuture when: #result: send: #markReturn: to: self.
	aFuture when: #exception: send: #markException: to: self.
	agent1 sendMessage: (Message selector: #beep)
		to: Smalltalk
		future: aFuture.
! !


!DispatchQueueTest methodsFor: 'accessing'!
msgQueue
	"Answer the receiver's instance variable msgQueue."

	^msgQueue! !

!DispatchQueueTest methodsFor: 'asserting'!
gotMessage

	^ gotMessage! !

!DispatchQueueTest methodsFor: 'asserting' stamp: 'rww 1/13/2002 22:43'!
printMessage: aMessage 

"
	Transcript cr; show: self class name , '>>', self selector asString, '  ' , aMessage printString."
	gotMessage := true.
! !

!DispatchQueueTest methodsFor: 'asserting' stamp: 'rww 1/15/2002 02:25'!
receiveMessage: aMessage 

	gotMessage := true.
! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 11/28/2000 12:51'!
setUp

	gotMessage := false.! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 11/28/2000 12:55'!
tearDown

	self msgQueue ifNotNil: [self msgQueue suspend. msgQueue := nil.].! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 1/15/2002 02:25'!
testBackgroundNoActionRemovalQueue
	| instCount |
	Smalltalk garbageCollect.
	instCount _ DispatchQueue instanceCount.
	msgQueue _ DispatchQueue new.
	self msgQueue background.
	self msgQueue priority: Processor userInterruptPriority.
	self msgQueue
		asyncSend: #receiveMessage:
		to: self
		with: 'hello world'.
	self assert: self gotMessage.
	self msgQueue close.
	msgQueue _ nil.
	Smalltalk garbageCollect.
	self assert: instCount - DispatchQueue instanceCount == 0! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 1/15/2002 02:25'!
testBackgroundNoActionRemovalWithWeakArrayQueue
	| ref |
	msgQueue _ DispatchQueue new.
	ref _ WeakArray with: msgQueue.
	self msgQueue background.
	self msgQueue priority: Processor userInterruptPriority.
	self msgQueue
		asyncSend: #receiveMessage:
		to: self
		with: 'hello world'.
	self assert: self gotMessage.
	self msgQueue close.
	msgQueue _ nil.
	Smalltalk garbageCollect.
	self assert: ref first isNil! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 1/15/2002 02:25'!
testBackgroundQueue
	msgQueue _ DispatchQueue new.
	gotMessage _ false.
	self msgQueue background.
	self msgQueue priority: Processor userInterruptPriority.
	self msgQueue
		asyncSend: #receiveMessage:
		to: self
		with: 'hello world'.
	self assert: self gotMessage.
	self msgQueue close.
	msgQueue _ nil! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rw 2/16/2002 18:53'!
testForegroundQueue
	msgQueue _ DispatchQueue new.
	msgQueue foreground.
	gotMessage _ false.
	self msgQueue
		asyncSend: #receiveMessage:
		to: self
		with: 'hello world'.
	self msgQueue dispatch.
	self assert: self gotMessage.
	self msgQueue close.
	msgQueue _ nil! !

!DispatchQueueTest methodsFor: 'running' stamp: 'rww 1/18/2002 22:26'!
testLotsBackgroundQueue
	msgQueue _ DispatchQueue new.
	gotMessage _ false.
	self msgQueue background.
	self msgQueue priority: Processor userInterruptPriority.
	1 to: 100 do: [:e | self msgQueue
		asyncSend: #receiveMessage:
		to: self
		with: 'hello world: ', e printString].
	self assert: self gotMessage.
	self msgQueue close.
	msgQueue _ nil! !


!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:23'!
setUp

	future := Future new.
! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:23'!
tearDown
	future _ nil! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:26'!
testExceptionSet
	[future exception: Exception new] fork.
	self should: [future value]
		raise: Exception.! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:39'!
testValueInterrupt
	[future interrupt] fork.
	self
		should: [future value]
		raise: FutureInterrupted! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:31'!
testValueSet
	[future value: 1] fork.
	self assert: future value = 1!
]style[(12 3 6 8 1 9 4 9 6 10)f1b,f1,f1cmagenta;,f1,f1c194194118,f1,f1cmagenta;,f1,f1cmagenta;,f1! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:41'!
testValueSetWait
	[(Delay forMilliseconds: 5) wait.
	future value: 1] fork.
	self
		should: [future valueTimeoutMSecs: 1]
		raise: FutureTimeout.
	self assert: future value = 1! !

!FutureTestCase methodsFor: 'running' stamp: 'rww 8/27/2001 00:39'!
testValueWait

	self should: [future valueTimeoutMSecs: 1]
		raise: FutureTimeout! !


!TaskTestCase methodsFor: 'signalling' stamp: 'rww 9/8/2000 17:38'!
signalMultiTaskRun

	count := count + 1.
	(self count >= self countLimit)
		ifTrue: [self signalTaskRun].
	! !

!TaskTestCase methodsFor: 'signalling' stamp: 'rww 9/8/2000 16:41'!
signalTaskRun

	self semTouched: true.
	self taskRunSem signal.
	! !

!TaskTestCase methodsFor: 'signalling' stamp: 'rww 9/8/2000 17:30'!
waitForTaskRun

	self taskRunSem waitTimeoutMSecs: 500.
	^self semTouched
! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 17:38'!
count

	^count! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 17:38'!
countLimit

	^countLimit! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 17:39'!
countLimit: anInteger

	countLimit := anInteger! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 16:40'!
semTouched

	^semTouched
! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 16:41'!
semTouched: aBool

	semTouched := aBool
! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 16:27'!
task

	^task! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 16:37'!
task: aTask

	task := aTask.
! !

!TaskTestCase methodsFor: 'accessing' stamp: 'rww 9/8/2000 16:34'!
taskRunSem

	^ taskRunSem
 
! !

!TaskTestCase methodsFor: 'running' stamp: 'rww 9/8/2000 17:40'!
setUp

	taskRunSem := Semaphore new.
	count := 0.
	self semTouched: false.

! !

!TaskTestCase methodsFor: 'running' stamp: 'rww 9/8/2000 16:37'!
tearDown

	taskRunSem := nil.
! !

!TaskTestCase methodsFor: 'running' stamp: 'rw 2/16/2002 15:09'!
testMultipleTask

	| accum |
	accum := 6.
	self countLimit: 6.
	self task: (Task
		taskAction: [self signalMultiTaskRun]
		shouldRescheduleAction: [accum := accum - 1. accum >= 1]).
	task start. 	
	self assert: (self waitForTaskRun).
	task stop.
! !

!TaskTestCase methodsFor: 'running' stamp: 'rw 2/16/2002 15:09'!
testSingleTask

	self task: (Task
		taskAction: [self signalTaskRun]
		shouldRescheduleAction: false).
	self task start.
	self assert: (self waitForTaskRun).
	self task stop.
! !


!TaskTestCase reorganize!
('signalling' signalMultiTaskRun signalTaskRun waitForTaskRun)
('accessing' count countLimit countLimit: semTouched semTouched: task task: taskRunSem)
('running' setUp tearDown testMultipleTask testSingleTask)
!

